package EntityModel::Support::CPP;
BEGIN {
  $EntityModel::Support::CPP::VERSION = '0.011';
}
use EntityModel::Class {
};

=head1 NAME

EntityModel::Support::CPP - C++ language support for L<EntityModel>

=head1 VERSION

version 0.011

=head1 SYNOPSIS

See L<EntityModel>.

=head1 DESCRIPTION

See L<EntityModel>.

=head1 METHODS

=cut

1;

__END__

=head1 AUTHOR

Tom Molesworth <cpan@entitymodel.com>

=head1 LICENSE

Copyright Tom Molesworth 2008-2011. Licensed under the same terms as Perl itself.